summaryrefslogtreecommitdiff
path: root/addons/analytic_user_function
diff options
context:
space:
mode:
authorXavier Morel <xmo@odoo.com>2015-06-24 17:06:17 +0200
committerXavier Morel <xmo@odoo.com>2015-06-25 10:39:55 +0200
commitd1a19bcb7f0f41b80f6df3afefb2753a2222d887 (patch)
tree1bdb2af93454c86fd712ff228b7ad522bc6611df /addons/analytic_user_function
parent443c38dbc0a9b70f9d0d1177ae50d52ade72d84e (diff)
[IMP] base: performances of view._check_xml
View validation accounts for a fair cost of module installation, most of that is spent checking for view validity, and a significant fraction of *that* is spent reading the validated view from the DB. Turns out _check_xml requested *all* view fields even though it needed none of them save for the arch. Specifying fields to read_combined rather than fetching all fields seems to result in a ~30% speedup of _check_xml (under line_profiler). Most of the rest is spent fetching sub-views (in get_inheriting_view_arch), I don't know that it can be improved without hand-crafting a fairly complex SQL request.
Diffstat (limited to 'addons/analytic_user_function')
0 files changed, 0 insertions, 0 deletions